@@ -7,7 +7,7 @@ use Carp qw(croak);
 use Mock::Sub::Child;
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 sub new {
     my $self = bless {}, shift;
@@ -39,7 +39,7 @@ sub mock {
     $child->return_value($self->{return_value});
 
     $self->{objects}{$sub}{obj} = $child;
-    $child->mock($sub);
+    $child->_mock($sub);
 
     # remove the REFCNT to the child, or else DESTROY won't be called
     weaken $self->{objects}{$sub}{obj};
@@ -107,8 +107,7 @@ Mock::Sub - Mock package, object and standard subroutines, with unit testing in
 
     my $mock = Mock::Sub->new;
 
-    # mock some subs... all of the following are children under the
-    # umbrella of the above $mock object we created
+    # mock some subs...
 
     my $foo = $mock->mock('Package::foo');
     my $bar = $mock->mock('Package::bar');
@@ -125,45 +124,36 @@ Mock::Sub - Mock package, object and standard subroutines, with unit testing in
     $foo->called_with;  # array of params sent to sub
 
     # have the mocked sub return something when it's called (list or scalar).
-    # See new() to find out how to set a return value once and have it used in
-    # all child mocked subs
 
     $foo->return_value(1, 2, {a => 1});
     my @return = Package::foo;
 
-    # have the mocked sub perform an action (the side effect function receives
-    # the parameters sent into the mocked sub). See new() to find out how to
-    # set side_effect up once, and have it copied to all child mocked subs
+    # have the mocked sub perform an action
 
     $foo->side_effect( sub { die "eval catch" if @_; } );
 
     eval { Package::foo(1); };
     like ($@, qr/eval catch/, "side_effect worked with params");
 
-    # extract the parameters the sub was called with (best if you know what
-    # the original sub is expecting)
+    # extract the parameters the sub was called with
 
     my @args = $foo->called_with;
 
-    # reset the mock object for re-use within the same scope (does not restore
-    # the mocked sub)
+    # reset the mock object for re-use within the same scope
 
     $foo->reset;
 
-    # restore original functionality to the sub (we do this by default on
-    # DESTROY()). This also calls reset() on the ojbect
+    # restore original functionality to the sub
 
     $foo->unmock;
 
-    # re-mock a sub using the same object after unmocking (this is the only
-    # time void context with mock() is permitted). Note that child mocks don't
-    # take a sub parameter to mock(), as they simply re-mock their original sub
+    # re-mock a previously unmock()ed sub
 
-    $foo->mock;
+    $foo->remock;
 
     # check if a sub is mocked
 
-    my $state = $foo->state;
+    my $state = $foo->mocked_state;
 
     # mock out a CORE:: function. Be warned that this *must* be done within
     # compile stage (BEGIN), and the function can NOT be unmocked prior
@@ -173,7 +163,6 @@ Mock::Sub - Mock package, object and standard subroutines, with unit testing in
 
     BEGIN {
         $mock = Mock::Sub->new;
-        # core function caller() is now mocked permanently after the following line
         $caller = $mock->mock('caller');
     };
 
@@ -213,7 +202,7 @@ MyModule::first).
         my $arg = shift;
         
         if ($arg == 1){
-            # how do you test this... there's no return etc.
+            # how do you test this?... there's no return etc.
             $other->first();        
         }
         if ($arg == 2){
@@ -251,14 +240,14 @@ Optional options:
 
 =over 4
 
-=item C<return_value>
+=item C<return_value =E<gt> $scalar>
 
 Set this to have all mocked subs created with this mock object return anything
 you wish (accepts a single scalar only. See C<return_value()> method to return
 a list and for further information). You can also set it in individual mocks
-only (see C<mock()>).
+only (see C<return_value()> method).
 
-=item C<side_effect>
+=item C<side_effect =E<gt> $cref>
 
 Set this in C<new()> to have the side effect passed into all child mocks
 created with this object. See C<side_effect()> method.
@@ -267,21 +256,21 @@ created with this object. See C<side_effect()> method.
 
 =head2 C<mock('sub', %opts)>
 
-Instantiates and returns a new mock object on each call (calling in
-void context is not permitted). 'sub' is the name of the subroutine to mock
-(requires full package name if the sub isn't in C<main::>.
+Instantiates and returns a new mock object on each call. 'sub' is the name of
+the subroutine to mock (requires full package name if the sub isn't in
+C<main::>).
 
 The mocked sub will return undef if a return value isn't set, or a side effect
 doesn't return anything.
 
-Optional options:
+Optional parameters:
 
-Both C<return_value> and C<side_effect> can be set in this method to
-individualize each mock object. Set in C<new> to have all mock objects use
-the same configuration.
+See C<new()> for a description of the parameters. Both the C<return_value> and
+C<side_effect> parameters can be set in this method to individualize each mock
+object, and will override the global configuration if set in C<new()>.
 
 There's also C<return_value()> and C<side_effect()> methods if you want to
-set, change or remove these values after instantiation.
+set, change or remove these values after instantiation of a child sub object.
 
 =head2 mocked_subs
 
@@ -296,7 +285,7 @@ if its sub is currently mocked or not.
 =head2 mocked_state('Sub::Name')
 
 Returns whether a sub currently under the parent mock object is mocked or not.
-Croaks if there is no object with the sub name parameter.
+Croaks if there hasn't been a child sub object created with this sub name.
 
 =head1 SUB OBJECT METHODS
 
@@ -304,15 +293,16 @@ These methods are for the children mocked sub objects returned from the
 parent mock object. See L<MOCK OBJECT METHODS> for methods related
 to the parent mock object.
 
-=head2 C<mock>
-
-Re-mocks the sub within the object after calling C<unmock> on it.
-
 =head2 C<unmock>
 
 Restores the original functionality back to the sub, and runs C<reset()> on
 the object.
 
+=head2 C<remock>
+
+Re-mocks the sub within the object after calling C<unmock> on it (accepts the
+side_effect and return_value parameters).
+
 =head2 C<called>
 
 Returns true if the sub being mocked has been called.
@@ -328,19 +318,19 @@ we're called before the mocked sub has been called.
 
 =head2 C<mocked_state>
 
-Returns true if the sub the object refers to is currently mocked, and false if
+Returns true (1) if the sub the object refers to is currently mocked, and false if
 not.
 
 =head2 C<name>
 
-Returns the full name of the sub being mocked, as entered into C<mock()>.
+Returns the name of the sub being mocked.
 
 =head2 C<side_effect($cref)>
 
-Add (or change/remove) a side effect after instantiation.
+Add (or change/delete) a side effect after instantiation.
 
 Send in a code reference containing an action you'd like the
-mocked sub to perform (C<die()> is useful for testing with C<eval()>).
+mocked sub to perform.
 
 The side effect function will receive all parameters sent into the mocked sub.
 
@@ -355,13 +345,14 @@ it does: C<sub { ...; undef; }>.
 
 =head2 C<return_value>
 
-Add (or change, delete) the mocked sub's return value after instantiation.
-Can be a scalar or list. Send in C<undef> to remove a previously set value.
+Add (or change/delete) the mocked sub's return value after instantiation.
+Can be a scalar or list. Send in C<undef> to remove previously set values.
 
 =head2 C<reset>
 
 Resets the functional parameters (C<return_value>, C<side_effect>), along
-with C<called()> and C<called_count()> back to undef/false.
+with C<called()> and C<called_count()> back to undef/false. Does not restore
+the sub back to its original state.
 
 =head1 NOTES
 
